==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/is.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'is', {
	acccessKey: 'Skammvalshnappur',
	advanced: 'Tæknilegt',
	advisoryContentType: 'Tegund innihalds',
	advisoryTitle: 'Titill',
	anchor: {
		toolbar: 'Stofna/breyta kaflamerki',
		menu: 'Eigindi kaflamerkis',
		title: 'Eigindi kaflamerkis',
		name: 'Nafn bókamerkis',
		errorName: 'Sláðu inn nafn bókamerkis!',
		remove: 'Remove Anchor'
	},
	anchorId: 'Eftir auðkenni einingar',
	anchorName: 'Eftir akkerisnafni',
	charset: 'Táknróf',
	cssClasses: 'Stílsniðsflokkur',
	emailAddress: 'Netfang',
	emailBody: 'Meginmál',
	emailSubject: 'Efni',
	id: 'Auðkenni',
	info: 'Almennt',
	langCode: 'Lesstefna',
	langDir: 'Lesstefna',
	langDirLTR: 'Frá vinstri til hægri (LTR)',
	langDirRTL: 'Frá hægri til vinstri (RTL)',
	menu: 'Breyta stiklu',
	name: 'Nafn',
	noAnchors: '<Engin bókamerki á skrá>',
	noEmail: 'Sláðu inn netfang!',
	noUrl: 'Sláðu inn veffang stiklunnar!',
	other: '<annar>',
	popupDependent: 'Háð venslum (Netscape)',
	popupFeatures: 'Eigindi sprettiglugga',
	popupFullScreen: 'Heilskjár (IE)',
	popupLeft: 'Fjarlægð frá vinstri',
	popupLocationBar: 'Fanglína',
	popupMenuBar: 'Vallína',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Skrunstikur',
	popupStatusBar: 'Stöðustika',
	popupToolbar: 'Verkfærastika',
	popupTop: 'Fjarlægð frá efri brún',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Veldu akkeri',
	styles: 'Stíll',
	tabIndex: 'Raðnúmer innsláttarreits',
	target: 'Mark',
	targetFrame: '<rammi>',
	targetFrameName: 'Nafn markglugga',
	targetPopup: '<sprettigluggi>',
	targetPopupName: 'Nafn sprettiglugga',
	title: 'Stikla',
	toAnchor: 'Bókamerki á þessari síðu',
	toEmail: 'Netfang',
	toUrl: 'Vefslóð',
	toolbar: 'Stofna/breyta stiklu',
	type: 'Stikluflokkur',
	unlink: 'Fjarlægja stiklu',
	upload: 'Senda upp'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/is.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'is', {
	acccessKey: 'Skammvalshnappur',
	advanced: 'Tæknilegt',
	advisoryContentType: 'Tegund innihalds',
	advisoryTitle: 'Titill',
	anchor: {
		toolbar: 'Stofna/breyta kaflamerki',
		menu: 'Eigindi kaflamerkis',
		title: 'Eigindi kaflamerkis',
		name: 'Nafn bókamerkis',
		errorName: 'Sláðu inn nafn bókamerkis!',
		remove: 'Remove Anchor'
	},
	anchorId: 'Eftir auðkenni einingar',
	anchorName: 'Eftir akkerisnafni',
	charset: 'Táknróf',
	cssClasses: 'Stílsniðsflokkur',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Netfang',
	emailBody: 'Meginmál',
	emailSubject: 'Efni',
	id: 'Auðkenni',
	info: 'Almennt',
	langCode: 'Lesstefna',
	langDir: 'Lesstefna',
	langDirLTR: 'Frá vinstri til hægri (LTR)',
	langDirRTL: 'Frá hægri til vinstri (RTL)',
	menu: 'Breyta stiklu',
	name: 'Nafn',
	noAnchors: '<Engin bókamerki á skrá>',
	noEmail: 'Sláðu inn netfang!',
	noUrl: 'Sláðu inn veffang stiklunnar!',
	noTel: 'Please type the phone number', // MISSING
	other: '<annar>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Háð venslum (Netscape)',
	popupFeatures: 'Eigindi sprettiglugga',
	popupFullScreen: 'Heilskjár (IE)',
	popupLeft: 'Fjarlægð frá vinstri',
	popupLocationBar: 'Fanglína',
	popupMenuBar: 'Vallína',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Skrunstikur',
	popupStatusBar: 'Stöðustika',
	popupToolbar: 'Verkfærastika',
	popupTop: 'Fjarlægð frá efri brún',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Veldu akkeri',
	styles: 'Stíll',
	tabIndex: 'Raðnúmer innsláttarreits',
	target: 'Mark',
	targetFrame: '<rammi>',
	targetFrameName: 'Nafn markglugga',
	targetPopup: '<sprettigluggi>',
	targetPopupName: 'Nafn sprettiglugga',
	title: 'Stikla',
	toAnchor: 'Bókamerki á þessari síðu',
	toEmail: 'Netfang',
	toUrl: 'Vefslóð',
	toPhone: 'Phone', // MISSING
	toolbar: 'Stofna/breyta stiklu',
	type: 'Stikluflokkur',
	unlink: 'Fjarlægja stiklu',
	upload: 'Senda upp'
} );
